@@ -14,3 +14,7 @@ test_that("ki_group_list returns a tibble with three columns", {
 test_that("ki_group_list throws error if no hub specified", {
   expect_error(ki_group_list())
 })
+
+test_that("ki_group_list throws error if provided hub in not reachable", {
+  expect_error(ki_group_list(hub = "https://xxxxx"))
+})
